meta_package_manager.platform — Meta Package Manager 2.4.1 documentation

# `meta_package_manager.platform`

Helpers and utilities to identify and handle platform idiosyncracies.

`meta_package_manager.platform.` `MACOS` = u'macos'

  Constant used to identify OSes of the macOS family.

`meta_package_manager.platform.` `LINUX` = u'linux'

  Constant used to identify OSes of the Linux family.

`meta_package_manager.platform.` `WINDOWS` = u'windows'

  Constant used to identify OSes of the Windows family.

`meta_package_manager.platform.` `is_linux`()

  Return True only if current platform is of the Linux family.

`meta_package_manager.platform.` `is_macos`()

  Return True only if current platform is of the macOS family.

`meta_package_manager.platform.` `is_windows`()

  Return True only if current platform is of the Windows family.

`meta_package_manager.platform.` `current_os`()

  Return a 2-items tuple with ID and label of current OS.

`meta_package_manager.platform.` `os_label`(os_id)

  Return platform label for user-friendly output.